pub enum SessionError {
NotFound(Uuid),
Remote(String),
}Expand description
Why a route could not be matched to a session.
Variants
NotFound(Uuid)
No state is registered for the session the route targets.
Remote(String)
The remote end reported a session failure.