pub fn session_error_to_error(e: SessionError) -> ErrorExpand description
Convert a session error into the error type the SDK surfaces to callers.
pub fn session_error_to_error(e: SessionError) -> ErrorConvert a session error into the error type the SDK surfaces to callers.